==> gs2-cdk-1.0.8.tar.gz: gs2-cdk-1.0.8/src/gs2_cdk/lottery/model/__init__.py <==
# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from .Namespace import Namespace
from .options.NamespaceOptions import NamespaceOptions
from .LotteryModel import LotteryModel
from .options.LotteryModelOptions import LotteryModelOptions
from .enum.LotteryModelMode import LotteryModelMode
from .enum.LotteryModelMethod import LotteryModelMethod
from .options.LotteryModelMethodIsPrizeTableOptions import LotteryModelMethodIsPrizeTableOptions
from .options.LotteryModelMethodIsScriptOptions import LotteryModelMethodIsScriptOptions
from .PrizeTable import PrizeTable
from .options.PrizeTableOptions import PrizeTableOptions
from .Prize import Prize
from .options.PrizeOptions import PrizeOptions
from .enum.PrizeType import PrizeType
from .options.PrizeTypeIsActionOptions import PrizeTypeIsActionOptions
from .options.PrizeTypeIsPrizeTableOptions import PrizeTypeIsPrizeTableOptions
from .PrizeLimit import PrizeLimit
from .options.PrizeLimitOptions import PrizeLimitOptions
from .DrawnPrize import DrawnPrize
from .options.DrawnPrizeOptions import DrawnPrizeOptions
from .BoxItem import BoxItem
from .options.BoxItemOptions import BoxItemOptions
from .CurrentMasterData import CurrentMasterData

==> gs2-cdk-1.0.86.tar.gz: gs2-cdk-1.0.86/src/gs2_cdk/lottery/model/__init__.py <==
# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from .Namespace import Namespace
from .options.NamespaceOptions import NamespaceOptions
from .LotteryModel import LotteryModel
from .options.LotteryModelOptions import LotteryModelOptions
from .enum.LotteryModelMode import LotteryModelMode
from .enum.LotteryModelMethod import LotteryModelMethod
from .options.LotteryModelMethodIsPrizeTableOptions import LotteryModelMethodIsPrizeTableOptions
from .options.LotteryModelMethodIsScriptOptions import LotteryModelMethodIsScriptOptions
from .PrizeTable import PrizeTable
from .options.PrizeTableOptions import PrizeTableOptions
from .Prize import Prize
from .options.PrizeOptions import PrizeOptions
from .enum.PrizeType import PrizeType
from .options.PrizeTypeIsActionOptions import PrizeTypeIsActionOptions
from .options.PrizeTypeIsPrizeTableOptions import PrizeTypeIsPrizeTableOptions
from .PrizeLimit import PrizeLimit
from .options.PrizeLimitOptions import PrizeLimitOptions
from .DrawnPrize import DrawnPrize
from .options.DrawnPrizeOptions import DrawnPrizeOptions
from .BoxItem import BoxItem
from .options.BoxItemOptions import BoxItemOptions
from .VerifyActionResult import VerifyActionResult
from .options.VerifyActionResultOptions import VerifyActionResultOptions
from .ConsumeActionResult import ConsumeActionResult
from .options.ConsumeActionResultOptions import ConsumeActionResultOptions
from .AcquireActionResult import AcquireActionResult
from .options.AcquireActionResultOptions import AcquireActionResultOptions
from .TransactionResult import TransactionResult
from .options.TransactionResultOptions import TransactionResultOptions
from .CurrentMasterData import CurrentMasterData
